#
# spec file for package perl-Net-SNMP
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Net-SNMP
%define         cpan_name Net-SNMP
Summary:        Object oriented interface to SNMP
License:        GPL-1.0+ or Artistic-1.0
Group:          Development/Libraries/Perl
Version:        6.0.1
Release:        23.1
Url:            http://search.cpan.org/dist/Net-SNMP/
#Source:         http://www.cpan.org/modules/by-module/Net/Net-SNMP-v%{version}.tar.gz
Source:         %{cpan_name}-v%{version}.tar.gz
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{perl_requires}
# MANUAL
BuildRequires:  netcfg
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Carp)
BuildRequires:  perl(Crypt::DES) >= 2.03
BuildRequires:  perl(Crypt::Rijndael) >= 1.02
BuildRequires:  perl(Digest::HMAC) >= 1.00
BuildRequires:  perl(Digest::MD5) >= 2.11
BuildRequires:  perl(Digest::SHA1) >= 1.02
BuildRequires:  perl(Errno)
BuildRequires:  perl(Exporter)
BuildRequires:  perl(IO::Socket)
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(Socket6) >= 0.23
Requires:       perl(Carp)
Requires:       perl(Crypt::DES) >= 2.03
Requires:       perl(Crypt::Rijndael) >= 1.02
Requires:       perl(Digest::HMAC) >= 1.00
Requires:       perl(Digest::MD5) >= 2.11
Requires:       perl(Digest::SHA1) >= 1.02
Requires:       perl(Errno)
Requires:       perl(Exporter)
Requires:       perl(IO::Socket)
Requires:       perl(Socket6) >= 0.23

%description
The Net::SNMP module abstracts the intricate details of the Simple
Network Management Protocol by providing a high level programming
interface to the protocol. Each Net::SNMP object provides a one-to-one
mapping between a Perl object and a remote SNMP agent or manager. Once an
object is created, it can be used to perform the basic protocol exchange
actions defined by SNMP.

Authors:
--------
    David M. Town <dtown@fore.com>

%prep
%setup -q -n %{cpan_name}-v%{version}

%build
%{__perl} Build.PL installdirs=vendor
./Build

%check
./Build test

%install
./Build install destdir=$RPM_BUILD_ROOT create_packlist=0
%perl_gen_filelist

%clean
%{__rm} -rf $RPM_BUILD_ROOT

%files -f %{name}.files
%defattr(-,root,root,-)
%doc Changes LICENSE README examples

%changelog
* Mon Oct 15 2012 coolo@suse.com
- buildrequire netcfg for the test suite
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Nov 19 2010 lars@linux-schulserver.de
- update to v6.0.1
  + Removed all occurrences of the "locked" attribute that was
    deprecated in Perl 5.12.0.
  + Changed the test validating the presence of a monotonic time value
    to check for invalid implementations.
  + The SNMPv3 contextEngineID and contextName are now stored as part
    of the request allowing for these values to be changed between
    messages.
- also package the examples
* Tue Jul 27 2010 chris@computersalat.de
- update to v6.0.0
- Substantial internal code cleanup was performed based upon the
  Perl::Critic module and the "Perl Best Practices" book.
- Added support for the Module::Build system for building, testing,
  and installing Perl modules.
- The translation logic for OCTET STRINGs now uses the definition of
  a DisplayString in RFC 2579 to determine if the octets are to be
  converted into a hexadecimal representation.
- The get_table() and get_entries() methods were refactored as part
  of the code cleanup.  The get_entries() method now handles "holes"
  in tables better and indexes with a value of zero.
- The inheritance structure of the Transport Domain objects was
  updated to reduce code duplication and increase maintainability.
- The resolution of IPv6 addresses was made more exhaustive.
- The handling of OBJECT IDENTIFIERs was made more efficient by
  using [un]pack() with a BER compressed integer template.
- Additional validation of the values passed to most methods is now
  performed and the error messages have been made more robust.
- The documented examples were updated based upon commonly asked
  questions (specifically Example 3 and Example 4).
- A Response-PDU with an error-status set to "noError" no longer
  generates an error when the error-index is non-zero, as decribed
  in Section 4.2.4 of RFC 3416.
- The function oid_lex_cmp() was added to provide for the
  lexicographical comparison of two OBJECT IDENTIFIERs.
- The error-status is no longer set for the exceptions noSuchObject,
  noSuchInstance, and endOfMibView when translation is not enabled.
- recreated by cpanspec 1.78
- noarch pkg
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan  6 2006 anicka@suse.cz
- update to 5.2.0
* Mon Aug  1 2005 cthiel@suse.de
- update to version 5.1.0
* Thu Feb 17 2005 mjancar@suse.cz
- update to 5.0.1
* Fri Aug  6 2004 mjancar@suse.cz
- update to 5.0.0
* Sun Jun 20 2004 ro@suse.de
- fix find command in specfile
* Sat Feb 28 2004 ro@suse.de
- fix requirement for /usr/local
* Wed Oct 22 2003 mjancar@suse.cz
- update to 4.1.2
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Jul 17 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Tue Jun 17 2003 mjancar@suse.cz
- fix filelist
* Fri Jun  6 2003 mjancar@suse.cz
- update to 4.1.0
- don't package MANIFEST
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Fri Dec 20 2002 prehak@suse.cz
- updated to version 4.0.3
* Tue Aug  6 2002 ro@suse.de
- change neededforbuild perl-Cryptix -> perl-Crypt-DES
* Mon Jul 29 2002 mls@suse.de
- Fixed neededforbuild for perl-5.8.0
* Mon Jul 22 2002 prehak@suse.cz
- update to version 4.0.2
- added examples directory to documentation
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Thu Jan 17 2002 rvasice@suse.cz
- update to version 4.0.1
* Mon Mar 26 2001 cihlar@suse.cz
- added make test
* Fri Nov 10 2000 cihlar@suse.cz
- renamed p_nsnmp -> perl-Net-SNMP
- update to version 3.60
* Thu Aug 24 2000 cihlar@suse.cz
- package created
